/****************************************************************************
** Meta object code from reading C++ file 'qsciscintillabase.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/QScintilla_gpl-2.10.1/Qt4Qt5/Qsci/qsciscintillabase.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qsciscintillabase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_QsciScintillaBase_t {
    QByteArrayData data[49];
    char stringdata0[677];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QsciScintillaBase_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QsciScintillaBase_t qt_meta_stringdata_QsciScintillaBase = {
    {
QT_MOC_LITERAL(0, 0, 17), // "QsciScintillaBase"
QT_MOC_LITERAL(1, 18, 15), // "QSCN_SELCHANGED"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 3), // "yes"
QT_MOC_LITERAL(4, 39, 18), // "SCN_AUTOCCANCELLED"
QT_MOC_LITERAL(5, 58, 20), // "SCN_AUTOCCHARDELETED"
QT_MOC_LITERAL(6, 79, 18), // "SCN_AUTOCCOMPLETED"
QT_MOC_LITERAL(7, 98, 11), // "const char*"
QT_MOC_LITERAL(8, 110, 9), // "selection"
QT_MOC_LITERAL(9, 120, 8), // "position"
QT_MOC_LITERAL(10, 129, 2), // "ch"
QT_MOC_LITERAL(11, 132, 6), // "method"
QT_MOC_LITERAL(12, 139, 18), // "SCN_AUTOCSELECTION"
QT_MOC_LITERAL(13, 158, 11), // "SCEN_CHANGE"
QT_MOC_LITERAL(14, 170, 16), // "SCN_CALLTIPCLICK"
QT_MOC_LITERAL(15, 187, 9), // "direction"
QT_MOC_LITERAL(16, 197, 13), // "SCN_CHARADDED"
QT_MOC_LITERAL(17, 211, 9), // "charadded"
QT_MOC_LITERAL(18, 221, 15), // "SCN_DOUBLECLICK"
QT_MOC_LITERAL(19, 237, 4), // "line"
QT_MOC_LITERAL(20, 242, 9), // "modifiers"
QT_MOC_LITERAL(21, 252, 12), // "SCN_DWELLEND"
QT_MOC_LITERAL(22, 265, 14), // "SCN_DWELLSTART"
QT_MOC_LITERAL(23, 280, 11), // "SCN_FOCUSIN"
QT_MOC_LITERAL(24, 292, 12), // "SCN_FOCUSOUT"
QT_MOC_LITERAL(25, 305, 16), // "SCN_HOTSPOTCLICK"
QT_MOC_LITERAL(26, 322, 22), // "SCN_HOTSPOTDOUBLECLICK"
QT_MOC_LITERAL(27, 345, 23), // "SCN_HOTSPOTRELEASECLICK"
QT_MOC_LITERAL(28, 369, 18), // "SCN_INDICATORCLICK"
QT_MOC_LITERAL(29, 388, 20), // "SCN_INDICATORRELEASE"
QT_MOC_LITERAL(30, 409, 15), // "SCN_MACRORECORD"
QT_MOC_LITERAL(31, 425, 15), // "SCN_MARGINCLICK"
QT_MOC_LITERAL(32, 441, 6), // "margin"
QT_MOC_LITERAL(33, 448, 20), // "SCN_MARGINRIGHTCLICK"
QT_MOC_LITERAL(34, 469, 12), // "SCN_MODIFIED"
QT_MOC_LITERAL(35, 482, 19), // "SCN_MODIFYATTEMPTRO"
QT_MOC_LITERAL(36, 502, 13), // "SCN_NEEDSHOWN"
QT_MOC_LITERAL(37, 516, 11), // "SCN_PAINTED"
QT_MOC_LITERAL(38, 528, 17), // "SCN_SAVEPOINTLEFT"
QT_MOC_LITERAL(39, 546, 20), // "SCN_SAVEPOINTREACHED"
QT_MOC_LITERAL(40, 567, 15), // "SCN_STYLENEEDED"
QT_MOC_LITERAL(41, 583, 12), // "SCN_UPDATEUI"
QT_MOC_LITERAL(42, 596, 7), // "updated"
QT_MOC_LITERAL(43, 604, 21), // "SCN_USERLISTSELECTION"
QT_MOC_LITERAL(44, 626, 8), // "SCN_ZOOM"
QT_MOC_LITERAL(45, 635, 9), // "handleVSb"
QT_MOC_LITERAL(46, 645, 5), // "value"
QT_MOC_LITERAL(47, 651, 9), // "handleHSb"
QT_MOC_LITERAL(48, 661, 15) // "handleSelection"

    },
    "QsciScintillaBase\0QSCN_SELCHANGED\0\0"
    "yes\0SCN_AUTOCCANCELLED\0SCN_AUTOCCHARDELETED\0"
    "SCN_AUTOCCOMPLETED\0const char*\0selection\0"
    "position\0ch\0method\0SCN_AUTOCSELECTION\0"
    "SCEN_CHANGE\0SCN_CALLTIPCLICK\0direction\0"
    "SCN_CHARADDED\0charadded\0SCN_DOUBLECLICK\0"
    "line\0modifiers\0SCN_DWELLEND\0SCN_DWELLSTART\0"
    "SCN_FOCUSIN\0SCN_FOCUSOUT\0SCN_HOTSPOTCLICK\0"
    "SCN_HOTSPOTDOUBLECLICK\0SCN_HOTSPOTRELEASECLICK\0"
    "SCN_INDICATORCLICK\0SCN_INDICATORRELEASE\0"
    "SCN_MACRORECORD\0SCN_MARGINCLICK\0margin\0"
    "SCN_MARGINRIGHTCLICK\0SCN_MODIFIED\0"
    "SCN_MODIFYATTEMPTRO\0SCN_NEEDSHOWN\0"
    "SCN_PAINTED\0SCN_SAVEPOINTLEFT\0"
    "SCN_SAVEPOINTREACHED\0SCN_STYLENEEDED\0"
    "SCN_UPDATEUI\0updated\0SCN_USERLISTSELECTION\0"
    "SCN_ZOOM\0handleVSb\0value\0handleHSb\0"
    "handleSelection"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QsciScintillaBase[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      36,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      33,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  194,    2, 0x06 /* Public */,
       4,    0,  197,    2, 0x06 /* Public */,
       5,    0,  198,    2, 0x06 /* Public */,
       6,    4,  199,    2, 0x06 /* Public */,
      12,    4,  208,    2, 0x06 /* Public */,
      12,    2,  217,    2, 0x06 /* Public */,
      13,    0,  222,    2, 0x06 /* Public */,
      14,    1,  223,    2, 0x06 /* Public */,
      16,    1,  226,    2, 0x06 /* Public */,
      18,    3,  229,    2, 0x06 /* Public */,
      21,    3,  236,    2, 0x06 /* Public */,
      22,    3,  243,    2, 0x06 /* Public */,
      23,    0,  250,    2, 0x06 /* Public */,
      24,    0,  251,    2, 0x06 /* Public */,
      25,    2,  252,    2, 0x06 /* Public */,
      26,    2,  257,    2, 0x06 /* Public */,
      27,    2,  262,    2, 0x06 /* Public */,
      28,    2,  267,    2, 0x06 /* Public */,
      29,    2,  272,    2, 0x06 /* Public */,
      30,    3,  277,    2, 0x06 /* Public */,
      31,    3,  284,    2, 0x06 /* Public */,
      33,    3,  291,    2, 0x06 /* Public */,
      34,   10,  298,    2, 0x06 /* Public */,
      35,    0,  319,    2, 0x06 /* Public */,
      36,    2,  320,    2, 0x06 /* Public */,
      37,    0,  325,    2, 0x06 /* Public */,
      38,    0,  326,    2, 0x06 /* Public */,
      39,    0,  327,    2, 0x06 /* Public */,
      40,    1,  328,    2, 0x06 /* Public */,
      41,    1,  331,    2, 0x06 /* Public */,
      43,    4,  334,    2, 0x06 /* Public */,
      43,    2,  343,    2, 0x06 /* Public */,
      44,    0,  348,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      45,    1,  349,    2, 0x08 /* Private */,
      47,    1,  352,    2, 0x08 /* Private */,
      48,    0,  355,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int, QMetaType::Int,    8,    9,   10,   11,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int, QMetaType::Int,    8,    9,   10,   11,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int,    8,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   19,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   20,
    QMetaType::Void, QMetaType::UInt, QMetaType::ULong, QMetaType::VoidStar,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   20,   32,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   20,   32,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, 0x80000000 | 7, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,   42,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int, QMetaType::Int, QMetaType::Int,    2,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Int,    2,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,   46,
    QMetaType::Void, QMetaType::Int,   46,
    QMetaType::Void,

       0        // eod
};

void QsciScintillaBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QsciScintillaBase *_t = static_cast<QsciScintillaBase *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->QSCN_SELCHANGED((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->SCN_AUTOCCANCELLED(); break;
        case 2: _t->SCN_AUTOCCHARDELETED(); break;
        case 3: _t->SCN_AUTOCCOMPLETED((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 4: _t->SCN_AUTOCSELECTION((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 5: _t->SCN_AUTOCSELECTION((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->SCEN_CHANGE(); break;
        case 7: _t->SCN_CALLTIPCLICK((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->SCN_CHARADDED((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->SCN_DOUBLECLICK((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 10: _t->SCN_DWELLEND((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 11: _t->SCN_DWELLSTART((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 12: _t->SCN_FOCUSIN(); break;
        case 13: _t->SCN_FOCUSOUT(); break;
        case 14: _t->SCN_HOTSPOTCLICK((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 15: _t->SCN_HOTSPOTDOUBLECLICK((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 16: _t->SCN_HOTSPOTRELEASECLICK((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 17: _t->SCN_INDICATORCLICK((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 18: _t->SCN_INDICATORRELEASE((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 19: _t->SCN_MACRORECORD((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< ulong(*)>(_a[2])),(*reinterpret_cast< void*(*)>(_a[3]))); break;
        case 20: _t->SCN_MARGINCLICK((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 21: _t->SCN_MARGINRIGHTCLICK((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 22: _t->SCN_MODIFIED((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const char*(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])),(*reinterpret_cast< int(*)>(_a[8])),(*reinterpret_cast< int(*)>(_a[9])),(*reinterpret_cast< int(*)>(_a[10]))); break;
        case 23: _t->SCN_MODIFYATTEMPTRO(); break;
        case 24: _t->SCN_NEEDSHOWN((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 25: _t->SCN_PAINTED(); break;
        case 26: _t->SCN_SAVEPOINTLEFT(); break;
        case 27: _t->SCN_SAVEPOINTREACHED(); break;
        case 28: _t->SCN_STYLENEEDED((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 29: _t->SCN_UPDATEUI((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 30: _t->SCN_USERLISTSELECTION((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 31: _t->SCN_USERLISTSELECTION((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 32: _t->SCN_ZOOM(); break;
        case 33: _t->handleVSb((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 34: _t->handleHSb((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 35: _t->handleSelection(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (QsciScintillaBase::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::QSCN_SELCHANGED)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_AUTOCCANCELLED)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_AUTOCCHARDELETED)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(const char * , int , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_AUTOCCOMPLETED)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(const char * , int , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_AUTOCSELECTION)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(const char * , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_AUTOCSELECTION)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCEN_CHANGE)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_CALLTIPCLICK)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_CHARADDED)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_DOUBLECLICK)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_DWELLEND)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_DWELLSTART)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_FOCUSIN)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_FOCUSOUT)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_HOTSPOTCLICK)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_HOTSPOTDOUBLECLICK)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_HOTSPOTRELEASECLICK)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_INDICATORCLICK)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_INDICATORRELEASE)) {
                *result = 18;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(unsigned int , unsigned long , void * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_MACRORECORD)) {
                *result = 19;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_MARGINCLICK)) {
                *result = 20;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_MARGINRIGHTCLICK)) {
                *result = 21;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int , const char * , int , int , int , int , int , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_MODIFIED)) {
                *result = 22;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_MODIFYATTEMPTRO)) {
                *result = 23;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_NEEDSHOWN)) {
                *result = 24;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_PAINTED)) {
                *result = 25;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_SAVEPOINTLEFT)) {
                *result = 26;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_SAVEPOINTREACHED)) {
                *result = 27;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_STYLENEEDED)) {
                *result = 28;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_UPDATEUI)) {
                *result = 29;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(const char * , int , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_USERLISTSELECTION)) {
                *result = 30;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)(const char * , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_USERLISTSELECTION)) {
                *result = 31;
                return;
            }
        }
        {
            typedef void (QsciScintillaBase::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&QsciScintillaBase::SCN_ZOOM)) {
                *result = 32;
                return;
            }
        }
    }
}

const QMetaObject QsciScintillaBase::staticMetaObject = {
    { &QAbstractScrollArea::staticMetaObject, qt_meta_stringdata_QsciScintillaBase.data,
      qt_meta_data_QsciScintillaBase,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *QsciScintillaBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QsciScintillaBase::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_QsciScintillaBase.stringdata0))
        return static_cast<void*>(const_cast< QsciScintillaBase*>(this));
    return QAbstractScrollArea::qt_metacast(_clname);
}

int QsciScintillaBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void QsciScintillaBase::QSCN_SELCHANGED(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QsciScintillaBase::SCN_AUTOCCANCELLED()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void QsciScintillaBase::SCN_AUTOCCHARDELETED()
{
    QMetaObject::activate(this, &staticMetaObject, 2, Q_NULLPTR);
}

// SIGNAL 3
void QsciScintillaBase::SCN_AUTOCCOMPLETED(const char * _t1, int _t2, int _t3, int _t4)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QsciScintillaBase::SCN_AUTOCSELECTION(const char * _t1, int _t2, int _t3, int _t4)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QsciScintillaBase::SCN_AUTOCSELECTION(const char * _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QsciScintillaBase::SCEN_CHANGE()
{
    QMetaObject::activate(this, &staticMetaObject, 6, Q_NULLPTR);
}

// SIGNAL 7
void QsciScintillaBase::SCN_CALLTIPCLICK(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void QsciScintillaBase::SCN_CHARADDED(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void QsciScintillaBase::SCN_DOUBLECLICK(int _t1, int _t2, int _t3)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void QsciScintillaBase::SCN_DWELLEND(int _t1, int _t2, int _t3)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void QsciScintillaBase::SCN_DWELLSTART(int _t1, int _t2, int _t3)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void QsciScintillaBase::SCN_FOCUSIN()
{
    QMetaObject::activate(this, &staticMetaObject, 12, Q_NULLPTR);
}

// SIGNAL 13
void QsciScintillaBase::SCN_FOCUSOUT()
{
    QMetaObject::activate(this, &staticMetaObject, 13, Q_NULLPTR);
}

// SIGNAL 14
void QsciScintillaBase::SCN_HOTSPOTCLICK(int _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void QsciScintillaBase::SCN_HOTSPOTDOUBLECLICK(int _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void QsciScintillaBase::SCN_HOTSPOTRELEASECLICK(int _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void QsciScintillaBase::SCN_INDICATORCLICK(int _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void QsciScintillaBase::SCN_INDICATORRELEASE(int _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void QsciScintillaBase::SCN_MACRORECORD(unsigned int _t1, unsigned long _t2, void * _t3)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void QsciScintillaBase::SCN_MARGINCLICK(int _t1, int _t2, int _t3)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void QsciScintillaBase::SCN_MARGINRIGHTCLICK(int _t1, int _t2, int _t3)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 21, _a);
}

// SIGNAL 22
void QsciScintillaBase::SCN_MODIFIED(int _t1, int _t2, const char * _t3, int _t4, int _t5, int _t6, int _t7, int _t8, int _t9, int _t10)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)), const_cast<void*>(reinterpret_cast<const void*>(&_t7)), const_cast<void*>(reinterpret_cast<const void*>(&_t8)), const_cast<void*>(reinterpret_cast<const void*>(&_t9)), const_cast<void*>(reinterpret_cast<const void*>(&_t10)) };
    QMetaObject::activate(this, &staticMetaObject, 22, _a);
}

// SIGNAL 23
void QsciScintillaBase::SCN_MODIFYATTEMPTRO()
{
    QMetaObject::activate(this, &staticMetaObject, 23, Q_NULLPTR);
}

// SIGNAL 24
void QsciScintillaBase::SCN_NEEDSHOWN(int _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 24, _a);
}

// SIGNAL 25
void QsciScintillaBase::SCN_PAINTED()
{
    QMetaObject::activate(this, &staticMetaObject, 25, Q_NULLPTR);
}

// SIGNAL 26
void QsciScintillaBase::SCN_SAVEPOINTLEFT()
{
    QMetaObject::activate(this, &staticMetaObject, 26, Q_NULLPTR);
}

// SIGNAL 27
void QsciScintillaBase::SCN_SAVEPOINTREACHED()
{
    QMetaObject::activate(this, &staticMetaObject, 27, Q_NULLPTR);
}

// SIGNAL 28
void QsciScintillaBase::SCN_STYLENEEDED(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 28, _a);
}

// SIGNAL 29
void QsciScintillaBase::SCN_UPDATEUI(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 29, _a);
}

// SIGNAL 30
void QsciScintillaBase::SCN_USERLISTSELECTION(const char * _t1, int _t2, int _t3, int _t4)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 30, _a);
}

// SIGNAL 31
void QsciScintillaBase::SCN_USERLISTSELECTION(const char * _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 31, _a);
}

// SIGNAL 32
void QsciScintillaBase::SCN_ZOOM()
{
    QMetaObject::activate(this, &staticMetaObject, 32, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
