/****************************************************************************
** Meta object code from reading C++ file 'qsciscintilla.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/QScintilla_gpl-2.10.1/Qt4Qt5/Qsci/qsciscintilla.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qsciscintilla.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_QsciScintilla[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
     111,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: signature, parameters, type, tag, flags
      26,   15,   14,   14, 0x05,
      61,   57,   14,   14, 0x05,
      98,   81,   14,   14, 0x05,
     146,   81,   14,   14, 0x05,
     195,   14,   14,   14, 0x05,
     228,  210,   14,   14, 0x05,
     273,  210,   14,   14, 0x05,
     323,   14,   14,   14, 0x05,
     349,  347,   14,   14, 0x05,
     375,   14,   14,   14, 0x05,
     394,   14,   14,   14, 0x05,
     418,  408,   14,   14, 0x05,

 // slots: signature, parameters, type, tag, flags
     454,  449,   14,   14, 0x0a,
     470,   14,   14,   14, 0x0a,
     492,   14,   14,   14, 0x0a,
     515,   14,   14,   14, 0x0a,
     542,   14,   14,   14, 0x0a,
     552,   14,   14,   14, 0x0a,
     560,   14,   14,   14, 0x0a,
     567,   14,   14,   14, 0x0a,
     573,   14,   14,   14, 0x0a,
     600,  595,   14,   14, 0x0a,
     632,  623,   14,   14, 0x0a,
     646,   14,   14,   14, 0x2a,
     656,  595,   14,   14, 0x0a,
     670,  595,   14,   14, 0x0a,
     682,  449,   14,   14, 0x0a,
     714,  698,   14,   14, 0x0a,
     740,   14,   14,   14, 0x0a,
     762,   14,   14,   14, 0x0a,
     770,   14,   14,   14, 0x0a,
     777,   14,   14,   14, 0x0a,
     798,  449,   14,   14, 0x0a,
     827,   14,   14,   14, 0x0a,
     859,   14,   14,   14, 0x0a,
     898,  891,   14,   14, 0x0a,
     914,   14,   14,   14, 0x2a,
     926,   14,   14,   14, 0x0a,
     953,  950,   14,   14, 0x0a,
    1000,  992,   14,   14, 0x0a,
    1042, 1035,   14,   14, 0x0a,
    1083, 1076,   14,   14, 0x0a,
    1136, 1129,   14,   14, 0x0a,
    1168, 1035,   14,   14, 0x0a,
    1231, 1220,   14,   14, 0x0a,
    1254, 1251,   14,   14, 0x0a,
    1292, 1283,   14,   14, 0x0a,
    1324, 1320,   14,   14, 0x0a,
    1356, 1320,   14,   14, 0x0a,
    1399, 1392,   14,   14, 0x0a,
    1431, 1425,   14,   14, 0x0a,
    1452, 1450,   14,   14, 0x0a,
    1469,   15,   14,   14, 0x0a,
    1501, 1496,   14,   14, 0x0a,
    1529, 1521,   14,   14, 0x0a,
    1564, 1552,   14,   14, 0x0a,
    1595, 1590,   14,   14, 0x2a,
    1634, 1617,   14,   14, 0x0a,
    1658, 1392,   14,   14, 0x0a,
    1685, 1320,   14,   14, 0x0a,
    1729, 1320,   14,   14, 0x0a,
    1778, 1773,   14,   14, 0x0a,
    1807, 1425,   14,   14, 0x0a,
    1838, 1832,   14,   14, 0x0a,
    1859,   14,   14,   14, 0x2a,
    1870, 1320,   14,   14, 0x0a,
    1906, 1904,   14,   14, 0x0a,
    1928, 1320,   14,   14, 0x0a,
    1974, 1962,   14,   14, 0x0a,
    2017, 2005,   14,   14, 0x0a,
    2058, 2046,   14,   14, 0x0a,
    2102, 2089,   14,   14, 0x0a,
    2135, 2126,   14,   14, 0x0a,
    2163,  347,   14,   14, 0x0a,
    2181, 1450,   14,   14, 0x0a,
    2201, 2198,   14,   14, 0x0a,
    2253, 2219,   14,   14, 0x0a,
    2283, 1320,   14,   14, 0x0a,
    2319, 1320,   14,   14, 0x0a,
    2362, 2355,   14,   14, 0x0a,
    2382, 1425,   14,   14, 0x0a,
    2399,  449,   14,   14, 0x0a,
    2419, 2416,   14,   14, 0x0a,
    2433, 1496,   14,   14, 0x0a,
    2479, 1496,   14,   14, 0x0a,
    2501,   14,   14,   14, 0x0a,
    2508,  595,   14,   14, 0x0a,
    2528, 2522,   14,   14, 0x0a,
    2540,   14,   14,   14, 0x0a,
    2549, 2522,   14,   14, 0x0a,
    2562,   14,   14,   14, 0x0a,
    2577, 2572,   14,   14, 0x0a,
    2593, 2589,   14,   14, 0x08,
    2627, 2617,   14,   14, 0x08,
    2662, 2648,   14,   14, 0x08,
    2692, 2648,   14,   14, 0x08,
    2745, 2724,   14,   14, 0x08,
    2776, 2724,   14,   14, 0x08,
    2886, 2812,   14,   14, 0x08,
    2959, 2950,   14,   14, 0x08,
    3005,   14,   14,   14, 0x08,
    3030,   14,   14,   14, 0x08,
    3052,   57,   14,   14, 0x08,
    3081,   14,   14,   14, 0x08,
    3121, 3113,   14,   14, 0x08,
    3170, 3162,   14,   14, 0x08,
    3219, 3205,   14,   14, 0x08,
    3262, 3254,   14,   14, 0x08,
    3295, 3162,   14,   14, 0x08,
    3338, 3330,   14,   14, 0x08,
    3358,   14,   14,   14, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_QsciScintilla[] = {
    "QsciScintilla\0\0line,index\0"
    "cursorPositionChanged(int,int)\0yes\0"
    "copyAvailable(bool)\0line,index,state\0"
    "indicatorClicked(int,int,Qt::KeyboardModifiers)\0"
    "indicatorReleased(int,int,Qt::KeyboardModifiers)\0"
    "linesChanged()\0margin,line,state\0"
    "marginClicked(int,int,Qt::KeyboardModifiers)\0"
    "marginRightClicked(int,int,Qt::KeyboardModifiers)\0"
    "modificationAttempted()\0m\0"
    "modificationChanged(bool)\0selectionChanged()\0"
    "textChanged()\0id,string\0"
    "userListActivated(int,QString)\0text\0"
    "append(QString)\0autoCompleteFromAll()\0"
    "autoCompleteFromAPIs()\0"
    "autoCompleteFromDocument()\0callTip()\0"
    "clear()\0copy()\0cut()\0ensureCursorVisible()\0"
    "line\0ensureLineVisible(int)\0children\0"
    "foldAll(bool)\0foldAll()\0foldLine(int)\0"
    "indent(int)\0insert(QString)\0text,line,index\0"
    "insertAt(QString,int,int)\0"
    "moveToMatchingBrace()\0paste()\0redo()\0"
    "removeSelectedText()\0replaceSelectedText(QString)\0"
    "resetSelectionBackgroundColor()\0"
    "resetSelectionForegroundColor()\0select\0"
    "selectAll(bool)\0selectAll()\0"
    "selectToMatchingBrace()\0cs\0"
    "setAutoCompletionCaseSensitivity(bool)\0"
    "replace\0setAutoCompletionReplaceWord(bool)\0"
    "single\0setAutoCompletionShowSingle(bool)\0"
    "source\0setAutoCompletionSource(AutoCompletionSource)\0"
    "thresh\0setAutoCompletionThreshold(int)\0"
    "setAutoCompletionUseSingle(AutoCompletionUseSingle)\0"
    "autoindent\0setAutoIndent(bool)\0bm\0"
    "setBraceMatching(BraceMatch)\0unindent\0"
    "setBackspaceUnindents(bool)\0col\0"
    "setCaretForegroundColor(QColor)\0"
    "setCaretLineBackgroundColor(QColor)\0"
    "enable\0setCaretLineVisible(bool)\0width\0"
    "setCaretWidth(int)\0c\0setColor(QColor)\0"
    "setCursorPosition(int,int)\0mode\0"
    "setEolMode(EolMode)\0visible\0"
    "setEolVisibility(bool)\0fold,margin\0"
    "setFolding(FoldStyle,int)\0fold\0"
    "setFolding(FoldStyle)\0line,indentation\0"
    "setIndentation(int,int)\0"
    "setIndentationGuides(bool)\0"
    "setIndentationGuidesBackgroundColor(QColor)\0"
    "setIndentationGuidesForegroundColor(QColor)\0"
    "tabs\0setIndentationsUseTabs(bool)\0"
    "setIndentationWidth(int)\0lexer\0"
    "setLexer(QsciLexer*)\0setLexer()\0"
    "setMarginsBackgroundColor(QColor)\0f\0"
    "setMarginsFont(QFont)\0"
    "setMarginsForegroundColor(QColor)\0"
    "margin,lnrs\0setMarginLineNumbers(int,bool)\0"
    "margin,mask\0setMarginMarkerMask(int,int)\0"
    "margin,sens\0setMarginSensitivity(int,bool)\0"
    "margin,width\0setMarginWidth(int,int)\0"
    "margin,s\0setMarginWidth(int,QString)\0"
    "setModified(bool)\0setPaper(QColor)\0"
    "ro\0setReadOnly(bool)\0"
    "lineFrom,indexFrom,lineTo,indexTo\0"
    "setSelection(int,int,int,int)\0"
    "setSelectionBackgroundColor(QColor)\0"
    "setSelectionForegroundColor(QColor)\0"
    "indent\0setTabIndents(bool)\0setTabWidth(int)\0"
    "setText(QString)\0cp\0setUtf8(bool)\0"
    "setWhitespaceVisibility(WhitespaceVisibility)\0"
    "setWrapMode(WrapMode)\0undo()\0unindent(int)\0"
    "range\0zoomIn(int)\0zoomIn()\0zoomOut(int)\0"
    "zoomOut()\0size\0zoomTo(int)\0dir\0"
    "handleCallTipClick(int)\0charadded\0"
    "handleCharAdded(int)\0pos,modifiers\0"
    "handleIndicatorClick(int,int)\0"
    "handleIndicatorRelease(int,int)\0"
    "pos,margin,modifiers\0"
    "handleMarginClick(int,int,int)\0"
    "handleMarginRightClick(int,int,int)\0"
    "pos,mtype,text,len,added,line,foldNow,foldPrev,token,annotationLinesAd"
    "ded\0"
    "handleModified(int,int,const char*,int,int,int,int,int,int,int)\0"
    "prop,val\0handlePropertyChange(const char*,const char*)\0"
    "handleSavePointReached()\0handleSavePointLeft()\0"
    "handleSelectionChanged(bool)\0"
    "handleAutoCompletionSelection()\0text,id\0"
    "handleUserListSelection(const char*,int)\0"
    "c,style\0handleStyleColorChange(QColor,int)\0"
    "eolfill,style\0handleStyleEolFillChange(bool,int)\0"
    "f,style\0handleStyleFontChange(QFont,int)\0"
    "handleStylePaperChange(QColor,int)\0"
    "updated\0handleUpdateUI(int)\0"
    "delete_selection()\0"
};

void QsciScintilla::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        QsciScintilla *_t = static_cast<QsciScintilla *>(_o);
        switch (_id) {
        case 0: _t->cursorPositionChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->copyAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->indicatorClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[3]))); break;
        case 3: _t->indicatorReleased((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[3]))); break;
        case 4: _t->linesChanged(); break;
        case 5: _t->marginClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[3]))); break;
        case 6: _t->marginRightClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[3]))); break;
        case 7: _t->modificationAttempted(); break;
        case 8: _t->modificationChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->selectionChanged(); break;
        case 10: _t->textChanged(); break;
        case 11: _t->userListActivated((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 12: _t->append((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->autoCompleteFromAll(); break;
        case 14: _t->autoCompleteFromAPIs(); break;
        case 15: _t->autoCompleteFromDocument(); break;
        case 16: _t->callTip(); break;
        case 17: _t->clear(); break;
        case 18: _t->copy(); break;
        case 19: _t->cut(); break;
        case 20: _t->ensureCursorVisible(); break;
        case 21: _t->ensureLineVisible((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->foldAll((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->foldAll(); break;
        case 24: _t->foldLine((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 25: _t->indent((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 26: _t->insert((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->insertAt((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 28: _t->moveToMatchingBrace(); break;
        case 29: _t->paste(); break;
        case 30: _t->redo(); break;
        case 31: _t->removeSelectedText(); break;
        case 32: _t->replaceSelectedText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 33: _t->resetSelectionBackgroundColor(); break;
        case 34: _t->resetSelectionForegroundColor(); break;
        case 35: _t->selectAll((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 36: _t->selectAll(); break;
        case 37: _t->selectToMatchingBrace(); break;
        case 38: _t->setAutoCompletionCaseSensitivity((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 39: _t->setAutoCompletionReplaceWord((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 40: _t->setAutoCompletionShowSingle((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 41: _t->setAutoCompletionSource((*reinterpret_cast< AutoCompletionSource(*)>(_a[1]))); break;
        case 42: _t->setAutoCompletionThreshold((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 43: _t->setAutoCompletionUseSingle((*reinterpret_cast< AutoCompletionUseSingle(*)>(_a[1]))); break;
        case 44: _t->setAutoIndent((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 45: _t->setBraceMatching((*reinterpret_cast< BraceMatch(*)>(_a[1]))); break;
        case 46: _t->setBackspaceUnindents((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 47: _t->setCaretForegroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 48: _t->setCaretLineBackgroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 49: _t->setCaretLineVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 50: _t->setCaretWidth((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 51: _t->setColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 52: _t->setCursorPosition((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 53: _t->setEolMode((*reinterpret_cast< EolMode(*)>(_a[1]))); break;
        case 54: _t->setEolVisibility((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 55: _t->setFolding((*reinterpret_cast< FoldStyle(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 56: _t->setFolding((*reinterpret_cast< FoldStyle(*)>(_a[1]))); break;
        case 57: _t->setIndentation((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 58: _t->setIndentationGuides((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 59: _t->setIndentationGuidesBackgroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 60: _t->setIndentationGuidesForegroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 61: _t->setIndentationsUseTabs((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 62: _t->setIndentationWidth((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 63: _t->setLexer((*reinterpret_cast< QsciLexer*(*)>(_a[1]))); break;
        case 64: _t->setLexer(); break;
        case 65: _t->setMarginsBackgroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 66: _t->setMarginsFont((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 67: _t->setMarginsForegroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 68: _t->setMarginLineNumbers((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 69: _t->setMarginMarkerMask((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 70: _t->setMarginSensitivity((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 71: _t->setMarginWidth((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 72: _t->setMarginWidth((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 73: _t->setModified((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 74: _t->setPaper((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 75: _t->setReadOnly((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 76: _t->setSelection((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 77: _t->setSelectionBackgroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 78: _t->setSelectionForegroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 79: _t->setTabIndents((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 80: _t->setTabWidth((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 81: _t->setText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 82: _t->setUtf8((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 83: _t->setWhitespaceVisibility((*reinterpret_cast< WhitespaceVisibility(*)>(_a[1]))); break;
        case 84: _t->setWrapMode((*reinterpret_cast< WrapMode(*)>(_a[1]))); break;
        case 85: _t->undo(); break;
        case 86: _t->unindent((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 87: _t->zoomIn((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 88: _t->zoomIn(); break;
        case 89: _t->zoomOut((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 90: _t->zoomOut(); break;
        case 91: _t->zoomTo((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 92: _t->handleCallTipClick((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 93: _t->handleCharAdded((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 94: _t->handleIndicatorClick((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 95: _t->handleIndicatorRelease((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 96: _t->handleMarginClick((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 97: _t->handleMarginRightClick((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 98: _t->handleModified((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const char*(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])),(*reinterpret_cast< int(*)>(_a[8])),(*reinterpret_cast< int(*)>(_a[9])),(*reinterpret_cast< int(*)>(_a[10]))); break;
        case 99: _t->handlePropertyChange((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< const char*(*)>(_a[2]))); break;
        case 100: _t->handleSavePointReached(); break;
        case 101: _t->handleSavePointLeft(); break;
        case 102: _t->handleSelectionChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 103: _t->handleAutoCompletionSelection(); break;
        case 104: _t->handleUserListSelection((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 105: _t->handleStyleColorChange((*reinterpret_cast< const QColor(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 106: _t->handleStyleEolFillChange((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 107: _t->handleStyleFontChange((*reinterpret_cast< const QFont(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 108: _t->handleStylePaperChange((*reinterpret_cast< const QColor(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 109: _t->handleUpdateUI((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 110: _t->delete_selection(); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData QsciScintilla::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject QsciScintilla::staticMetaObject = {
    { &QsciScintillaBase::staticMetaObject, qt_meta_stringdata_QsciScintilla,
      qt_meta_data_QsciScintilla, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &QsciScintilla::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *QsciScintilla::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *QsciScintilla::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_QsciScintilla))
        return static_cast<void*>(const_cast< QsciScintilla*>(this));
    return QsciScintillaBase::qt_metacast(_clname);
}

int QsciScintilla::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QsciScintillaBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 111)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 111;
    }
    return _id;
}

// SIGNAL 0
void QsciScintilla::cursorPositionChanged(int _t1, int _t2)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QsciScintilla::copyAvailable(bool _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QsciScintilla::indicatorClicked(int _t1, int _t2, Qt::KeyboardModifiers _t3)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QsciScintilla::indicatorReleased(int _t1, int _t2, Qt::KeyboardModifiers _t3)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QsciScintilla::linesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, 0);
}

// SIGNAL 5
void QsciScintilla::marginClicked(int _t1, int _t2, Qt::KeyboardModifiers _t3)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QsciScintilla::marginRightClicked(int _t1, int _t2, Qt::KeyboardModifiers _t3)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QsciScintilla::modificationAttempted()
{
    QMetaObject::activate(this, &staticMetaObject, 7, 0);
}

// SIGNAL 8
void QsciScintilla::modificationChanged(bool _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void QsciScintilla::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, 0);
}

// SIGNAL 10
void QsciScintilla::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, 0);
}

// SIGNAL 11
void QsciScintilla::userListActivated(int _t1, const QString & _t2)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}
QT_END_MOC_NAMESPACE
